@@ -8,7 +8,7 @@
  */
 
 /*  This file is part of AutoGen.
- *  Copyright (C) 1992-2013 Bruce Korb - all rights reserved
+ *  Copyright (C) 1992-2015 Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -26,6 +26,7 @@
 #ifdef HAVE_SYS_RESOURCE_H
 #include <sys/resource.h>
 #endif
+#include <locale.h>
 
 typedef void (void_main_proc_t)(int, char **);
 
@@ -38,9 +39,6 @@ typedef enum {
 static char const * const state_names[] = { STATE_TABLE };
 #undef _State_
 
-static sigjmp_buf  abend_env;
-static int         abend_sig = 0;
-
 typedef void (sighandler_proc_t)(int sig);
 static sighandler_proc_t ignore_signal, catch_sig_and_bail;
 
@@ -51,7 +49,7 @@ inner_main(void * closure, int argc, char ** argv);
 static void
 exit_cleanup(wait_for_pclose_enum_t cl_wait);
 
-static void
+static _Noreturn void
 cleanup_and_abort(int sig);
 
 static void
@@ -64,9 +62,9 @@ static void
 done_check(void);
 
 static void
-setup_signals(sighandler_proc_t * chldHandler,
-              sighandler_proc_t * abrtHandler,
-              sighandler_proc_t * dfltHandler);
+setup_signals(sighandler_proc_t * hdl_chld,
+              sighandler_proc_t * hdl_abrt,
+              sighandler_proc_t * hdl_dflt);
 /* = = = END-STATIC-FORWARD = = = */
 
 #ifndef HAVE_CHMOD
@@ -96,18 +94,18 @@ inner_main(void * closure, int argc, char ** argv)
     processing_state = PROC_STATE_LOAD_TPL;
 
     {
-        templ_t* pTF = tpl_load(tpl_fname, NULL);
+        templ_t * tpl = tpl_load(tpl_fname, NULL);
 
         processing_state = PROC_STATE_EMITTING;
-        process_tpl(pTF);
+        process_tpl(tpl);
 
         processing_state = PROC_STATE_CLEANUP;
-        cleanup(pTF);
+        cleanup(tpl);
     }
 
     processing_state = PROC_STATE_DONE;
     setup_signals(SIG_DFL, SIG_IGN, SIG_DFL);
-    exit_code = AUTOGEN_EXIT_SUCCESS;
+    ag_exit_code = AUTOGEN_EXIT_SUCCESS;
     done_check();
     /* NOTREACHED */
     (void)closure;
@@ -123,13 +121,7 @@ inner_main(void * closure, int argc, char ** argv)
 int
 main(int argc, char ** argv)
 {
-    /*
-     *  IF we've been kicked with a signal,
-     *  THEN abort, passing the signal that whacked us.
-     */
-    if (sigsetjmp(abend_env, 0) != 0)
-        cleanup_and_abort(abend_sig);
-
+    setlocale(LC_ALL, "");
     setup_signals(ignore_signal, SIG_DFL, catch_sig_and_bail);
     optionSaveState(&autogenOptions);
     trace_fp = stderr;
@@ -193,6 +185,7 @@ exit_cleanup(wait_for_pclose_enum_t cl_wait)
         }
     } while (false);
 
+    trace_fp = stderr;
     fflush(stdout);
     fflush(stderr);
 }
@@ -203,13 +196,12 @@ exit_cleanup(wait_for_pclose_enum_t cl_wait)
  *
  *  @param[in] sig the signal number
  */
-static void
+static _Noreturn void
 cleanup_and_abort(int sig)
 {
-    int sig_exit_code = AUTOGEN_EXIT_SIGNAL + sig;
     if (processing_state == PROC_STATE_INIT) {
         fprintf(stderr, AG_NEVER_STARTED, sig, strsignal(sig));
-        exit(sig_exit_code);
+        exit(AUTOGEN_EXIT_SIGNAL + sig);
     }
 
     if (*oops_pfx != NUL) {
@@ -223,7 +215,7 @@ cleanup_and_abort(int sig)
 
     if (processing_state == PROC_STATE_ABORTING) {
         exit_cleanup(EXIT_PCLOSE_NOWAIT);
-        exit(sig_exit_code);
+        abort();
     }
 
     processing_state = PROC_STATE_ABORTING;
@@ -288,15 +280,13 @@ catch_sig_and_bail(int sig)
 {
     switch (processing_state) {
     case PROC_STATE_ABORTING:
-        exit_code = AUTOGEN_EXIT_SIGNAL + sig;
+        ag_exit_code = AUTOGEN_EXIT_SIGNAL + sig;
 
     case PROC_STATE_DONE:
         break;
 
     default:
-        abend_sig = sig;
-        exit_code = AUTOGEN_EXIT_SIGNAL + sig;
-        siglongjmp(abend_env, sig);
+        cleanup_and_abort(sig);
     }
 }
 
@@ -372,11 +362,11 @@ done_check(void)
             out_close(true);
 #endif
         } while (cur_fpstack->stk_prev != NULL);
-        exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
+        ag_exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
         break; /* continue failure exit */
 
     case PROC_STATE_LOAD_DEFS:
-        exit_code = AUTOGEN_EXIT_BAD_DEFINITIONS;
+        ag_exit_code = AUTOGEN_EXIT_BAD_DEFINITIONS;
         /* FALLTHROUGH */
 
     default:
@@ -384,7 +374,7 @@ done_check(void)
         goto autogen_aborts;
 
     case PROC_STATE_ABORTING:
-        exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
+        ag_exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
 
     autogen_aborts:
         if (*oops_pfx != NUL) {
@@ -450,14 +440,14 @@ done_check(void)
      *  of inner_main().)
      */
     if (processing_state != PROC_STATE_OPTIONS)
-        exit(exit_code);
+        exit(ag_exit_code);
 }
 
 
-LOCAL void
-ag_abend_at(char const * pzMsg
+LOCAL _Noreturn void
+ag_abend_at(char const * msg
 #ifdef DEBUG_ENABLED
-            , char const * pzFile, int line
+            , char const * fname, int line
 #endif
     )
 {
@@ -467,23 +457,23 @@ ag_abend_at(char const * pzMsg
     }
 
 #ifdef DEBUG_ENABLED
-    fprintf(stderr, "Giving up in %s line %d\n", pzFile, line);
+    fprintf(stderr, "Giving up in %s line %d\n", fname, line);
 #endif
 
     if ((processing_state >= PROC_STATE_LIB_LOAD) && (current_tpl != NULL)) {
         int l_no = (cur_macro == NULL) ? -1 : cur_macro->md_line;
         fprintf(stderr, ERROR_IN_TPL_FMT, current_tpl->td_file, l_no);
     }
-    fputs(pzMsg, stderr);
-    pzMsg += strlen(pzMsg);
-    if (pzMsg[-1] != NL)
+    fputs(msg, stderr);
+    msg += strlen(msg);
+    if (msg[-1] != NL)
         fputc(NL, stderr);
 
     {
-        proc_state_t oldState = processing_state;
+        proc_state_t o_state = processing_state;
         processing_state = PROC_STATE_ABORTING;
 
-        switch (oldState) {
+        switch (o_state) {
         case PROC_STATE_EMITTING:
         case PROC_STATE_INCLUDING:
         case PROC_STATE_CLEANUP:
@@ -498,9 +488,9 @@ ag_abend_at(char const * pzMsg
 
 
 static void
-setup_signals(sighandler_proc_t * chldHandler,
-              sighandler_proc_t * abrtHandler,
-              sighandler_proc_t * dfltHandler)
+setup_signals(sighandler_proc_t * hdl_chld,
+              sighandler_proc_t * hdl_abrt,
+              sighandler_proc_t * hdl_dflt)
 {
     struct sigaction  sa;
     int    sigNo  = 1;
@@ -528,11 +518,11 @@ setup_signals(sighandler_proc_t * chldHandler,
 #  define SIGCHLD SIGCLD
 #endif
         case SIGCHLD:
-            sa.sa_handler = chldHandler;
+            sa.sa_handler = hdl_chld;
             break;
 
         case SIGABRT:
-            sa.sa_handler = abrtHandler;
+            sa.sa_handler = hdl_abrt;
             break;
 
             /*
@@ -591,7 +581,7 @@ setup_signals(sighandler_proc_t * chldHandler,
 #endif
 
         default:
-            sa.sa_handler = dfltHandler;
+            sa.sa_handler = hdl_dflt;
         }
         sigaction(sigNo,  &sa, NULL);
     } while (++sigNo < maxSig);
@@ -609,10 +599,8 @@ LOCAL void *
 ao_malloc (size_t sz)
 {
     void * res = malloc(sz);
-    if (res == NULL) {
-        fprintf(stderr, MALLOC_FAIL_FMT, sz);
-        exit(EXIT_FAILURE);
-    }
+    if (res == NULL)
+        die(AUTOGEN_EXIT_FS_ERROR, MALLOC_FAIL_FMT, sz);
     return res;
 }
 
@@ -621,10 +609,8 @@ LOCAL void *
 ao_realloc (void *p, size_t sz)
 {
     void * res = (p == NULL) ? malloc(sz) : realloc(p, sz);
-    if (res == NULL) {
-        fprintf(stderr, REALLOC_FAIL_FMT, sz, p);
-        exit(EXIT_FAILURE);
-    }
+    if (res == NULL)
+        die(AUTOGEN_EXIT_FS_ERROR, REALLOC_FAIL_FMT, sz, p);
     return res;
 }
 
@@ -632,10 +618,8 @@ LOCAL char *
 ao_strdup (char const * str)
 {
     char * res = strdup(str);
-    if (res == NULL) {
-        fprintf(stderr, STRDUP_FAIL_FMT, (int)strlen(str));
-        exit(EXIT_FAILURE);
-    }
+    if (res == NULL)
+        die(AUTOGEN_EXIT_FS_ERROR, STRDUP_FAIL_FMT, (int)strlen(str));
     return res;
 }
 
