@@ -10,7 +10,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2015 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -56,7 +56,7 @@ static SCM
 find_entry_value(SCM op, SCM obj, SCM test);
 
 static ver_type_t
-str2int_ver(char* pz);
+str2int_ver(char * pz);
 
 static SCM
 do_tpl_file_line(int line_delta, char const * fmt);
@@ -113,8 +113,8 @@ static SCM
 find_entry_value(SCM op, SCM obj, SCM test)
 {
     bool     isIndexed;
-    def_ent_t*  pE;
-    char*       pzField;
+    def_ent_t * pE;
+    char *      pzField;
 
     {
         char * name = ag_scm2zchars(obj, "find name");
@@ -248,9 +248,9 @@ ag_scm_base_name(void)
  *       @end example
 =*/
 static ver_type_t
-str2int_ver(char* pz)
+str2int_ver(char * pz)
 {
-    char* pzStr = pz;
+    char * pzStr = pz;
     ver_type_t  val = 0;
     int ix = 4;
 
@@ -304,7 +304,7 @@ ag_scm_version_compare(SCM op, SCM v1, SCM v2)
     ver_type_t val2 = str2int_ver(ag_scm2zchars(v2, "ver"));
     v1 = SCM_FROM(val1);
     v2 = SCM_FROM(val2);
-    return scm_apply(op, v1, scm_cons(v2, AG_SCM_LISTOFNULL()));
+    return scm_apply(op, v1, scm_cons(v2, scm_list_1(SCM_EOL)));
 }
 
 /*=gfunc count
@@ -324,7 +324,7 @@ ag_scm_count(SCM obj)
 {
     int ent_len = count_entries(ag_scm2zchars(obj, "ag object"));
 
-    return AG_SCM_INT2SCM(ent_len);
+    return scm_from_int(ent_len);
 }
 
 
@@ -555,7 +555,7 @@ ag_scm_get_down_name(SCM agName)
 SCM
 ag_scm_high_lim(SCM obj)
 {
-    def_ent_t*  pE;
+    def_ent_t *  pE;
     bool     isIndexed;
 
     pE = find_def_ent(ag_scm2zchars(obj, "ag value"), &isIndexed);
@@ -566,15 +566,15 @@ ag_scm_high_lim(SCM obj)
      *  ELSE search the twin list for the high entry
      */
     if (pE == NULL)
-        return AG_SCM_INT2SCM(0);
+        return scm_from_int(0);
 
     if (isIndexed)
-        return AG_SCM_INT2SCM((int)pE->de_index);
+        return scm_from_int((int)pE->de_index);
 
     if (pE->de_etwin != NULL)
         pE = pE->de_etwin;
 
-    return AG_SCM_INT2SCM((int)pE->de_index);
+    return scm_from_int((int)pE->de_index);
 }
 
 
@@ -595,7 +595,7 @@ ag_scm_len(SCM obj)
 {
     int len = entry_length(ag_scm2zchars(obj, "ag value"));
 
-    return AG_SCM_INT2SCM(len);
+    return scm_from_int(len);
 }
 
 
@@ -610,7 +610,7 @@ ag_scm_len(SCM obj)
 SCM
 ag_scm_low_lim(SCM obj)
 {
-    def_ent_t*  pE;
+    def_ent_t * pE;
     bool     x;
 
     pE = find_def_ent(ag_scm2zchars(obj, "ag value"), &x);
@@ -621,9 +621,9 @@ ag_scm_low_lim(SCM obj)
      *  ELSE we have the low index.
      */
     if (pE == NULL)
-        return AG_SCM_INT2SCM(0);
+        return scm_from_int(0);
 
-    return AG_SCM_INT2SCM((int)pE->de_index);
+    return scm_from_int((int)pE->de_index);
 }
 
 
@@ -654,7 +654,7 @@ ag_scm_set_option(SCM opt)
 SCM
 ag_scm_suffix(void)
 {
-    return AG_SCM_STR02SCM((char*)curr_sfx);
+    return AG_SCM_STR02SCM((char *)curr_sfx);
 }
 
 
@@ -672,7 +672,7 @@ ag_scm_suffix(void)
 SCM
 ag_scm_tpl_file(SCM full)
 {
-    if (AG_SCM_BOOL_P(full) && AG_SCM_NFALSEP(full)) {
+    if (scm_is_bool(full) && scm_is_true(full)) {
         static char const * const sfx[] = { TPL_FILE_TPL, NULL };
 
         char z[AG_PATH_MAX];
@@ -691,8 +691,8 @@ do_tpl_file_line(int line_delta, char const * fmt)
 {
     unsigned int ln_no = (unsigned int)cur_macro->md_line;
     void * args[2] = {
-        [0] = (void *)current_tpl->td_file,
-        [1] = (void *)(uintptr_t)(ln_no + (unsigned)line_delta)
+        [0] = VOIDP(current_tpl->td_file),
+        [1] = VOIDP(ln_no + (unsigned)line_delta)
     };
     char * buf = strrchr(args[0], DIRCH);
     if (buf != NULL)
@@ -703,7 +703,7 @@ do_tpl_file_line(int line_delta, char const * fmt)
         buf = scribble_get(sz);
     }
 
-    sprintfv(buf, fmt, (snv_constpointer*)args);
+    sprintfv(buf, fmt, (snv_constpointer *)args);
     return AG_SCM_STR02SCM(buf);
 }
 
@@ -803,8 +803,8 @@ ag_scm_def_file_line(SCM obj, SCM fmt)
 
     {
         void * args[2] = {
-            (void *)pE->de_file,
-            (void *)(uintptr_t)pE->de_line
+            VOIDP(pE->de_file),
+            VOIDP(pE->de_line)
         };
         ssize_t maxlen;
 
@@ -815,7 +815,7 @@ ag_scm_def_file_line(SCM obj, SCM fmt)
         maxlen = (ssize_t)(
             strlen(args[0]) + strlen(pzFmt) + LOG10_2to32 + 1);
         buf    = scribble_get(maxlen);
-        sprintfv(buf, pzFmt, (snv_constpointer*)args);
+        sprintfv(buf, pzFmt, (snv_constpointer *)args);
     }
 
     return AG_SCM_STR02SCM(buf);
