@@ -9,7 +9,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2015 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -33,7 +33,7 @@ static for_state_t *
 find_for_state(SCM which_scm);
 
 static bool
-next_def(bool invert, def_ent_t** de_lst);
+next_def(bool invert, def_ent_t ** de_lst);
 
 static int
 for_by_step(templ_t * pT, macro_t * pMac, def_ent_t * found);
@@ -43,6 +43,9 @@ for_each(templ_t * tpl, macro_t * mac, def_ent_t * def_ent);
 
 static void
 load_for_in(char const * pzSrc, size_t srcLen, templ_t * pT, macro_t * pMac);
+
+static for_state_t *
+new_for_context(void);
 /* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -159,7 +162,7 @@ ag_scm_for_index(SCM which)
     if (p == NULL)
         return SCM_UNDEFINED;
 
-    which = AG_SCM_INT2SCM(p->for_index);
+    which = scm_from_int(p->for_index);
     return which;
 }
 
@@ -176,7 +179,7 @@ ag_scm_for_index(SCM which)
 SCM
 ag_scm_for_from(SCM from)
 {
-    if ((! for_state->for_loading) || (! AG_SCM_NUM_P(from)))
+    if ((! for_state->for_loading) || (! scm_is_number(from)))
         return SCM_UNDEFINED;
 
     for_state->for_from = AG_SCM_TO_INT(from);
@@ -197,7 +200,7 @@ ag_scm_for_from(SCM from)
 SCM
 ag_scm_for_to(SCM to)
 {
-    if ((! for_state->for_loading) || (! AG_SCM_NUM_P(to)))
+    if ((! for_state->for_loading) || (! scm_is_number(to)))
         return SCM_UNDEFINED;
 
     for_state->for_to = AG_SCM_TO_INT(to);
@@ -218,7 +221,7 @@ ag_scm_for_to(SCM to)
 SCM
 ag_scm_for_by(SCM by)
 {
-    if ((! for_state->for_loading) || (! AG_SCM_NUM_P(by)))
+    if ((! for_state->for_loading) || (! scm_is_number(by)))
         return SCM_UNDEFINED;
 
     for_state->for_by = AG_SCM_TO_INT(by);
@@ -255,10 +258,10 @@ ag_scm_for_sep(SCM obj)
  * @param[in,out] de_lst  linked list of definitions
  */
 static bool
-next_def(bool invert, def_ent_t** de_lst)
+next_def(bool invert, def_ent_t ** de_lst)
 {
-    bool     haveMatch = false;
-    def_ent_t*  ent     = *de_lst;
+    bool     matched = false;
+    def_ent_t * ent  = *de_lst;
 
     while (ent != NULL) {
         /*
@@ -268,7 +271,7 @@ next_def(bool invert, def_ent_t** de_lst)
          *  THEN break out and use it
          */
         if (ent->de_index == for_state->for_index) {
-            haveMatch = true;
+            matched = true;
             break;
         }
 
@@ -287,7 +290,7 @@ next_def(bool invert, def_ent_t** de_lst)
              */
             if (for_state->for_by == 0) {
                 for_state->for_index = (int)ent->de_index;
-                haveMatch = true;
+                matched = true;
             }
             break;
         }
@@ -303,7 +306,7 @@ next_def(bool invert, def_ent_t** de_lst)
      *  Save our restart point and return the find indication
      */
     *de_lst = ent;
-    return haveMatch;
+    return matched;
 }
 
 static int
@@ -313,7 +316,6 @@ for_by_step(templ_t * pT, macro_t * pMac, def_ent_t * found)
     def_ent_t   textDef;
     bool        invert    = (for_state->for_by < 0) ? true : false;
     t_word      loopLimit = OPT_VALUE_LOOP_LIMIT;
-    def_ctx_t   ctx       = curr_def_ctx;
     macro_t *   end_mac   = pT->td_macros + pMac->md_end_idx;
 
     /*
@@ -391,7 +393,7 @@ for_by_step(templ_t * pT, macro_t * pMac, def_ent_t * found)
          *  IF we have a non-base definition, use the old def context
          */
         if (for_state->for_not_found)
-            curr_def_ctx = ctx;
+            curr_def_ctx = for_state->for_ctx;
 
         /*
          *  ELSE IF this macro is a text type
@@ -402,7 +404,7 @@ for_by_step(templ_t * pT, macro_t * pMac, def_ent_t * found)
             textDef.de_next    = textDef.de_twin = NULL;
 
             curr_def_ctx.dcx_defent = &textDef;
-            curr_def_ctx.dcx_prev = &ctx;
+            curr_def_ctx.dcx_prev = &for_state->for_ctx;
         }
 
         /*
@@ -411,7 +413,7 @@ for_by_step(templ_t * pT, macro_t * pMac, def_ent_t * found)
          */
         else {
             curr_def_ctx.dcx_defent = found->de_val.dvu_entry;
-            curr_def_ctx.dcx_prev = &ctx;
+            curr_def_ctx.dcx_prev = &for_state->for_ctx;
         }
 
         for_state->for_islast = (invert)
@@ -450,7 +452,6 @@ for_by_step(templ_t * pT, macro_t * pMac, def_ent_t * found)
         for_state->for_index   = next_ix;
     } leave_loop:
 
-    curr_def_ctx = ctx;  /* Restore the def context */
     return loopCt;
 }
 
@@ -458,10 +459,8 @@ static int
 for_each(templ_t * tpl, macro_t * mac, def_ent_t * def_ent)
 {
     int       loopCt  = 0;
-    def_ctx_t ctx     = curr_def_ctx;
     macro_t * end_mac = tpl->td_macros + mac->md_end_idx;
 
-    curr_def_ctx.dcx_prev = &ctx;
     mac++;
 
     for (;;) {
@@ -531,7 +530,6 @@ for_each(templ_t * tpl, macro_t * mac, def_ent_t * def_ent)
         fflush(cur_fpstack->stk_fp);
     } leave_loop:;
 
-    curr_def_ctx = ctx;  /* Restore the def context */
     return loopCt;
 }
 
@@ -540,9 +538,9 @@ for_each(templ_t * tpl, macro_t * mac, def_ent_t * def_ent)
 static void
 load_for_in(char const * pzSrc, size_t srcLen, templ_t * pT, macro_t * pMac)
 {
-    char* pzName = pT->td_text + pMac->md_name_off;
-    int   ix     = 0;
-    char* pz;
+    char * pzName = pT->td_text + pMac->md_name_off;
+    int    ix     = 0;
+    char * pz;
     def_ent_t * prev_ent = NULL;
 
     /*
@@ -567,7 +565,7 @@ load_for_in(char const * pzSrc, size_t srcLen, templ_t * pT, macro_t * pMac)
     pz[srcLen] = NUL;
 
     do  {
-        def_ent_t* pDef = new_def_ent();
+        def_ent_t * pDef = new_def_ent();
 
         pDef->de_name    = pzName;
         pDef->de_index   = ix++;
@@ -792,10 +790,7 @@ mFunc_For(templ_t * tpl, macro_t * mac)
             fprintf(trace_fp, TAB_FILE_LINE_FMT, tpl->td_file, mac->md_line);
     }
 
-    if (for_state->for_sep_str != NULL)
-        AGFREE(for_state->for_sep_str);
-
-    free_for_context(false);
+    free_for_context(1);
 
     return ret_mac;
 }
@@ -805,7 +800,7 @@ mFunc_For(templ_t * tpl, macro_t * mac)
  *
  * @returns the top of thecurr_ivk_info stack of contexts.
  */
-LOCAL for_state_t *
+static for_state_t *
 new_for_context(void)
 {
     for_state_t * res;
@@ -826,24 +821,39 @@ new_for_context(void)
     }
 
     res = curr_ivk_info->ii_for_data + (curr_ivk_info->ii_for_depth - 1);
-    memset((void*)res, 0, sizeof(for_state_t));
+    memset(VOIDP(res), 0, sizeof(for_state_t));
     res->for_isfirst = true;
+    res->for_ctx     = curr_def_ctx;
+    curr_def_ctx.dcx_prev = &res->for_ctx;
     return res;
 }
 
 /**
- * allocate and zero out a FOR macro context.
- *
- * @returns the top of thecurr_ivk_info stack of contexts.
+ * Free up for loop contexts.
+ * @param [in] pop_ct  the maximum number to free up
  */
 LOCAL void
-free_for_context(bool everything)
+free_for_context(int pop_ct)
 {
-    if ((--(curr_ivk_info->ii_for_depth) == 0) || everything) {
-        AGFREE(curr_ivk_info->ii_for_data);
-        curr_ivk_info->ii_for_data  = NULL;
-        curr_ivk_info->ii_for_alloc = 0;
-        curr_ivk_info->ii_for_depth = 0;
+    if (curr_ivk_info->ii_for_depth == 0)
+        return;
+
+    for_state = curr_ivk_info->ii_for_data + (curr_ivk_info->ii_for_depth - 1);
+
+    while (pop_ct-- > 0) {
+        if (for_state->for_sep_str != NULL)
+            AGFREE(for_state->for_sep_str);
+
+        curr_def_ctx = (for_state--)->for_ctx;
+
+        if (--(curr_ivk_info->ii_for_depth) <= 0) {
+            AGFREE(curr_ivk_info->ii_for_data);
+            curr_ivk_info->ii_for_data  = NULL;
+            curr_ivk_info->ii_for_alloc = 0;
+            curr_ivk_info->ii_for_depth = 0;
+            for_state = NULL;
+            break;
+        }
     }
 }
 
@@ -856,8 +866,8 @@ macro_t *
 mLoad_For(templ_t * tpl, macro_t * mac, char const ** p_scan)
 {
     char *        scan_out = tpl->td_scan; /* next text dest   */
-    char const *  scan_in  = (char const*)mac->md_txt_off; /* macro text */
-    size_t        in_len   = (size_t)mac->md_res;          /* macro len  */
+    char const *  scan_in  = (char const *)mac->md_txt_off; /* macro text */
+    size_t        in_len   = (size_t)mac->md_res;           /* macro len  */
 
     /*
      *  Save the global macro loading mode
@@ -874,7 +884,7 @@ mLoad_For(templ_t * tpl, macro_t * mac, char const ** p_scan)
      *  functions that are enabled only while processing a FOR macro
      */
     if (load_for_macro_procs[0] == NULL) {
-        memcpy((void*)load_for_macro_procs, base_load_table,
+        memcpy(VOIDP(load_for_macro_procs), base_load_table,
                sizeof(base_load_table));
         load_for_macro_procs[ FTYP_ENDFOR ] = &mLoad_Ending;
     }
@@ -904,7 +914,7 @@ mLoad_For(templ_t * tpl, macro_t * mac, char const ** p_scan)
      *  Skip space to the start of the text following the iterator name
      */
     scan_in = SPN_WHITESPACE_CHARS(scan_in);
-    in_len -= (size_t)(scan_in - (char*)mac->md_txt_off);
+    in_len -= (size_t)(scan_in - (char *)mac->md_txt_off);
 
     /* * * * *
      *
